# Diabetes-related health indicator dataset

Diabetes-related factors extracted from the CDC's Behavioral Risk Factor Surveillance System (BRFSS), year 2015.
The original BRFSS, from which this dataset is derived, is a health-related telephone survey that is collected 
annually by the CDC.

### Source
Dataset downloaded from [Kaggle](https://www.kaggle.com/datasets/alexteboul/diabetes-health-indicators-dataset).

### Example data-to-paper manuscript
Here is an [example Paper](https://github.com/rkishony/data-to-paper-supplementary/blob/main/Supplementary%20Data-chained%20Manuscripts/Supplementary%20Data-chained%20Manuscript%20A.pdf) created by data-to paper.

### How to run
`python run.py diabetes`
